searchNodes=[{"doc":"","ref":"gpio.html","title":"gpio","type":"module"},{"doc":"Return information about the open GPIO chip. This includes the name, label and number of available lines.","ref":"gpio.html#chip_info/1","title":"gpio.chip_info/1","type":"function"},{"doc":"Close a previously open GPIO chip.","ref":"gpio.html#close_chip/1","title":"gpio.close_chip/1","type":"function"},{"doc":"Close a previously opened line events.","ref":"gpio.html#close_line_events/1","title":"gpio.close_line_events/1","type":"function"},{"doc":"Close a previously opened lines.","ref":"gpio.html#close_lines/1","title":"gpio.close_lines/1","type":"function"},{"doc":"Open a GPIO chip given its full path. The path should normally look like &quot;/dev/gpiochipX&quot;. Once a chip is open, it can be used to query its info using chip_info/1 , open lines for reading/writing using open_lines/5 or monitor lines for input events using open_line_events/5 . The handle to the GPIO chip is automatically closed when the process that opened it terminates, it can also be closed explicitely using close_chip/1 . Returns a handle to use the GPIO chip in case of success.","ref":"gpio.html#open_chip/1","title":"gpio.open_chip/1","type":"function"},{"doc":"Open a set of lines for montoring. The lines to be opened are specified through the Offsets parameter, for example to open the 16th, 20th and 21st lines Offsets would be [16, 20, 21] . these offsets are board and system specific. The Flags allow specifying the active state as well as the drive mode. The EventFlags allow specifying how events are detected. The ConsumerLabel should be an ASCII string of the application name. This string will be truncated to 31 characters. Upon opening the lines for monitoring, the owning process will start receiving messages in the form of: { gpio , LineEventsHandle , { event , Timestamp , Type } } Where LineEventsHandle is the handle returned by this function, Timestamp is best estimate of time of event occurrence, in nanoseconds and Type is one of rising_edge or falling_edge . Returns a handle that can be used for ending the lines monitoring using close_line_events/1 .","ref":"gpio.html#open_line_events/5","title":"gpio.open_line_events/5","type":"function"},{"doc":"Open a set of lines for reading/writing. The lines to be opened are specified through the Offsets parameter, for example to open the 16th, 20th and 21st lines Offsets would be [16, 20, 21] . these offsets are board and system specific, make sure to consult the documentation of the system to avoid damages. The Flags allow specifying the pin direction, the active state as well as the drive mode. The Defaults parameter specifies the default pin values. The length of this list must be equal to the length of the Offsets` list. The `ConsumerLabel should be an ASCII string of the application name. This string will be truncated to 31 characters. Returns a handle to read from using read_lines/1 ; or write to using write_lines/2 ; the opened lines in case of success.","ref":"gpio.html#open_lines/5","title":"gpio.open_lines/5","type":"function"},{"doc":"Read the current value of a set of opened lines. Returns a tuple of 0 and 1 values. The tuple size is equal to the number of lines opened using open_lines/5 .","ref":"gpio.html#read_lines/1","title":"gpio.read_lines/1","type":"function"},{"doc":"Set the current value of a set of opened lines. The Values tuple must consiste of 0 and 1 values and its size must be equal to the number of lines opened using open_lines/5 .","ref":"gpio.html#write_lines/2","title":"gpio.write_lines/2","type":"function"},{"doc":"","ref":"gpio.html#t:chip/0","title":"gpio.chip/0","type":"opaque"},{"doc":"","ref":"gpio.html#t:chip_info/0","title":"gpio.chip_info/0","type":"type"},{"doc":"","ref":"gpio.html#t:line_events/0","title":"gpio.line_events/0","type":"opaque"},{"doc":"","ref":"gpio.html#t:lines/0","title":"gpio.lines/0","type":"opaque"},{"doc":"An Erlang application for interfacing with GPIOs on Linux systems. This GPIO application allows for reading and writing to GPIO pins as well as monitoring input GPIO pins. Setup You need to add gpio as a dependency to your project. If you are using rebar3 , you can add the following to your rebar.config : { deps , [ { gpio , &quot;0.6.2&quot; } ] } . Also ensure that gpio is added as a dependency to your application, by updating your .app.src file: { application , my_app , [ { applications , [ kernel , stdlib , gpio % &lt;- You need this in your applications list ] } ] } . Usage","ref":"readme.html","title":"Overview","type":"extras"},{"doc":"The following will open gpiochip2 (typically called GPIO3): &gt; { ok , Chip } = gpio : open_chip ( &quot;/dev/gpiochip2&quot; ) . { ok , # Ref &lt; 0.3061467712 . 2848194561.68326 &gt; } Once the chip is open you need to either use gpio:open_lines/5 if you want to read/write values to/from the lines, or gpio:open_line_events/5 if you want to monitor a line.","ref":"readme.html#opening-the-gpio-chip","title":"Overview - Opening the gpio chip","type":"extras"},{"doc":"The following will open a single line IO1 from the previously open chip (typically this would be GPIO3_IO1 ). The opened line is configured as an output with a default value of 0 . The last parameter is used to communicate to the kernel a description of the chip use. If debugfs is enabled, this information is visible in /sys/kernel/debug/gpio . &gt; { ok , SingleLine } = gpio : open_lines ( Chip , [ 1 ] , [ output ] , [ 0 ] , &quot;my-application&quot; ) . { ok , # Ref &lt; 0.3061467712 . 2848194561.68334 &gt; } To write a 0 to the GPIO line, you can use: ok = gpio : write_lines ( SingleLine , { 0 } ) . Alternatively, to write a 1 to the GPIO line, you can use: ok = gpio : write_lines ( SingleLine , { 1 } ) . The gpio:write_lines/2 function takes a tuple of 0 and 1 values. The arity of this tuple must be equal to the width of the lines. Previously, we opened a single line, which is why we use a single element tuple. If instead, we opened 2 lines, we would need to provide a 2 element tuple like below: &gt; { ok , MultiLines } = gpio : open_lines ( Chip , [ 1 , 2 , 5 ] , [ output ] , [ 0 , 0 , 0 ] , &quot;my-application&quot; ) . { ok , # Ref &lt; 0.3061467712 . 2848194561.68339 &gt; } &gt; ok = gpio : write_lines ( MultiLines , { 1 , 1 , 1 } ) . % Set all pins to 1 ok &gt; ok = gpio : write_lines ( MultiLines , { 1 , 0 , 1 } ) . % Set IO1 and IO5 to 1, IO2 is set to 0 ok","ref":"readme.html#opening-gpio-lines","title":"Overview - Opening gpio lines","type":"extras"},{"doc":"The following will monitor the pin IO10 ( GPIO3_I10 ) for rising values (changes from 0 to 1). &gt; { ok , LineEvents } = gpio : open_line_events ( Chip , 10 , [ input ] , [ rising_edge ] , &quot;my-application&quot; ) . { ok , { # Ref &lt; 0.3061467712 . 2848194561.68344 &gt; , &lt; 0.340 . 0 &gt; } } The monitoring process will then receive messages like the following: { gpio , LineEvents , { event , Timestamp , Type } } Where Timestamp is a system timestamp in nanosecond, and Type is either rising_edge or falling_edge . In case of an error, the process might receive a message like the following: { gpio , LineEvents , { error , Error } }","ref":"readme.html#monitoring-line-events","title":"Overview - Monitoring line events","type":"extras"},{"doc":"Version 2.0, January 2004 http://www.apache.org/licenses/ TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION","ref":"license.html","title":"License","type":"extras"},{"doc":"&quot;License&quot; shall mean the terms and conditions for use, reproduction, and distribution as defined by Sections 1 through 9 of this document. &quot;Licensor&quot; shall mean the copyright owner or entity authorized by the copyright owner that is granting the License. &quot;Legal Entity&quot; shall mean the union of the acting entity and all other entities that control, are controlled by, or are under common control with that entity. For the purposes of this definition, &quot;control&quot; means (i) the power, direct or indirect, to cause the direction or management of such entity, whether by contract or otherwise, or (ii) ownership of fifty percent (50%) or more of the outstanding shares, or (iii) beneficial ownership of such entity. &quot;You&quot; (or &quot;Your&quot;) shall mean an individual or Legal Entity exercising permissions granted by this License. &quot;Source&quot; form shall mean the preferred form for making modifications, including but not limited to software source code, documentation source, and configuration files. &quot;Object&quot; form shall mean any form resulting from mechanical transformation or translation of a Source form, including but not limited to compiled object code, generated documentation, and conversions to other media types. &quot;Work&quot; shall mean the work of authorship, whether in Source or Object form, made available under the License, as indicated by a copyright notice that is included in or attached to the work (an example is provided in the Appendix below). &quot;Derivative Works&quot; shall mean any work, whether in Source or Object form, that is based on (or derived from) the Work and for which the editorial revisions, annotations, elaborations, or other modifications represent, as a whole, an original work of authorship. For the purposes of this License, Derivative Works shall not include works that remain separable from, or merely link (or bind by name) to the interfaces of, the Work and Derivative Works thereof. &quot;Contribution&quot; shall mean any work of authorship, including the original version of the Work and any modifications or additions to that Work or Derivative Works thereof, that is intentionally submitted to Licensor for inclusion in the Work by the copyright owner or by an individual or Legal Entity authorized to submit on behalf of the copyright owner. For the purposes of this definition, &quot;submitted&quot; means any form of electronic, verbal, or written communication sent to the Licensor or its representatives, including but not limited to communication on electronic mailing lists, source code control systems, and issue tracking systems that are managed by, or on behalf of, the Licensor for the purpose of discussing and improving the Work, but excluding communication that is conspicuously marked or otherwise designated in writing by the copyright owner as &quot;Not a Contribution.&quot; &quot;Contributor&quot; shall mean Licensor and any individual or Legal Entity on behalf of whom a Contribution has been received by Licensor and subsequently incorporated within the Work.","ref":"license.html#1-definitions","title":"License - 1. Definitions.","type":"extras"},{"doc":"Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable copyright license to reproduce, prepare Derivative Works of, publicly display, publicly perform, sublicense, and distribute the Work and such Derivative Works in Source or Object form.","ref":"license.html#2-grant-of-copyright-license","title":"License - 2. Grant of Copyright License.","type":"extras"},{"doc":"Subject to the terms and conditions of this License, each Contributor hereby grants to You a perpetual, worldwide, non-exclusive, no-charge, royalty-free, irrevocable (except as stated in this section) patent license to make, have made, use, offer to sell, sell, import, and otherwise transfer the Work, where such license applies only to those patent claims licensable by such Contributor that are necessarily infringed by their Contribution(s) alone or by combination of their Contribution(s) with the Work to which such Contribution(s) was submitted. If You institute patent litigation against any entity (including a cross-claim or counterclaim in a lawsuit) alleging that the Work or a Contribution incorporated within the Work constitutes direct or contributory patent infringement, then any patent licenses granted to You under this License for that Work shall terminate as of the date such litigation is filed.","ref":"license.html#3-grant-of-patent-license","title":"License - 3. Grant of Patent License.","type":"extras"},{"doc":"You may reproduce and distribute copies of the Work or Derivative Works thereof in any medium, with or without modifications, and in Source or Object form, provided that You meet the following conditions: You must give any other recipients of the Work or Derivative Works a copy of this License; and You must cause any modified files to carry prominent notices stating that You changed the files; and You must retain, in the Source form of any Derivative Works that You distribute, all copyright, patent, trademark, and attribution notices from the Source form of the Work, excluding those notices that do not pertain to any part of the Derivative Works; and If the Work includes a &quot;NOTICE&quot; text file as part of its distribution, then any Derivative Works that You distribute must include a readable copy of the attribution notices contained within such NOTICE file, excluding those notices that do not pertain to any part of the Derivative Works, in at least one of the following places: within a NOTICE text file distributed as part of the Derivative Works; within the Source form or documentation, if provided along with the Derivative Works; or, within a display generated by the Derivative Works, if and wherever such third-party notices normally appear. The contents of the NOTICE file are for informational purposes only and do not modify the License. You may add Your own attribution notices within Derivative Works that You distribute, alongside or as an addendum to the NOTICE text from the Work, provided that such additional attribution notices cannot be construed as modifying the License. You may add Your own copyright statement to Your modifications and may provide additional or different license terms and conditions for use, reproduction, or distribution of Your modifications, or for any such Derivative Works as a whole, provided Your use, reproduction, and distribution of the Work otherwise complies with the conditions stated in this License.","ref":"license.html#4-redistribution","title":"License - 4. Redistribution.","type":"extras"},{"doc":"Unless You explicitly state otherwise, any Contribution intentionally submitted for inclusion in the Work by You to the Licensor shall be under the terms and conditions of this License, without any additional terms or conditions. Notwithstanding the above, nothing herein shall supersede or modify the terms of any separate license agreement you may have executed with Licensor regarding such Contributions.","ref":"license.html#5-submission-of-contributions","title":"License - 5. Submission of Contributions.","type":"extras"},{"doc":"This License does not grant permission to use the trade names, trademarks, service marks, or product names of the Licensor, except as required for reasonable and customary use in describing the origin of the Work and reproducing the content of the NOTICE file.","ref":"license.html#6-trademarks","title":"License - 6. Trademarks.","type":"extras"},{"doc":"Unless required by applicable law or agreed to in writing, Licensor provides the Work (and each Contributor provides its Contributions) on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied, including, without limitation, any warranties or conditions of TITLE, NON- INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A PARTICULAR PURPOSE. You are solely responsible for determining the appropriateness of using or redistributing the Work and assume any risks associated with Your exercise of permissions under this License.","ref":"license.html#7-disclaimer-of-warranty","title":"License - 7. Disclaimer of Warranty.","type":"extras"},{"doc":"In no event and under no legal theory, whether in tort (including negligence), contract, or otherwise, unless required by applicable law (such as deliberate and grossly negligent acts) or agreed to in writing, shall any Contributor be liable to You for damages, including any direct, indirect, special, incidental, or consequential damages of any character arising as a result of this License or out of the use or inability to use the Work (including but not limited to damages for loss of goodwill, work stoppage, computer failure or malfunction, or any and all other commercial damages or losses), even if such Contributor has been advised of the possibility of such damages.","ref":"license.html#8-limitation-of-liability","title":"License - 8. Limitation of Liability.","type":"extras"},{"doc":"While redistributing the Work or Derivative Works thereof, You may choose to offer, and charge a fee for, acceptance of support, warranty, indemnity, or other liability obligations and/or rights consistent with this License. However, in accepting such obligations, You may act only on Your own behalf and on Your sole responsibility, not on behalf of any other Contributor, and only if You agree to indemnify, defend, and hold each Contributor harmless for any liability incurred by, or claims asserted against, such Contributor by reason of your accepting any such warranty or additional liability. END OF TERMS AND CONDITIONS","ref":"license.html#9-accepting-warranty-or-additional-liability","title":"License - 9. Accepting Warranty or Additional Liability.","type":"extras"},{"doc":"Copyright, KOPERA AS &lt;hello@kopera.com&gt;. All Rights Reserved.","ref":"notice.html","title":"Copyright","type":"extras"}]